@@ -307,6 +307,12 @@ def _run_test_loop(tasks, session, run_tests):
 
 @pytest.hookspec
 def pytest_runtestloop(session):
+    if session.config.pluginmanager.is_registered("asyncio"):
+        raise Exception(
+            "pytest-asyncio-cooperative is NOT compatible with pytest-asyncio\n"
+            "Uninstall pytest-asyncio or pass this option to pytest: `-p no:asyncio`\n"
+        )
+
     session.wrapped_fixtures = {}
 
     flakes_to_retry = []
